@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use lib '../lib';
+use lib qw(../lib  lib);
 
 use POE qw(Component::IRC Component::IRC::Plugin::CPAN::Info);
 
